@@ -21,10 +21,11 @@ class Shard(Enum):
     XBOX_OC = 'xbox-oc'  # Oceania
     XBOX_SA = 'xbox-sa'  # South America
     KAKAO = 'kakao'  # Kakao
-    PSN = 'psn'
-    STEAM = 'steam'
+    PSN = 'psn'  # PSN (Deprecated)
+    STEAM = 'steam'  # Steam
     TOURNAMENT = 'tournament'  # Tournaments
-    XBOX = 'xbox'  # Xbox
+    XBOX = 'xbox'  # Xbox (Deprecated)
+    CONSOLE = 'console'  # Xbox/Psn
 
 
 class Filter(Enum):
@@ -198,14 +199,14 @@ class Season(Domain):
     def from_dict(self):
         super().from_dict()
         self.is_current_season = self.attributes.get('isCurrentSeason')
-        self.is_off_season = self.attributes.get('isOffSeason')
-        self.best_rank_point = self.attributes.get('bestRankPoint')
+        self.is_off_season = self.attributes.get('isOffseason')
 
 
 class Playerseason(Domain):
 
     def from_dict(self):
         super().from_dict()
+        self.best_rank_point = self.attributes.get('bestRankPoint')
         game_mode_stats = self.attributes.get('gameModeStats')
         self.solo = Stats({'data': game_mode_stats.get('solo', {})})
         self.solo_fpp = Stats({'data': game_mode_stats.get('solo-fpp', {})})
@@ -223,7 +224,7 @@ class Stats(Domain):
         super().from_dict()
         self.assists = self._data.get('assists')
         self.boosts = self._data.get('boosts')
-        self.dbnos = self._data.get('dbnos')
+        self.dbnos = self._data.get('dBNOs')
         self.daily_kills = self._data.get('dailyKills')
         self.damage_dealt = self._data.get('damageDealt')
         self.days = self._data.get('days')
@@ -262,3 +263,12 @@ class Leaderboard(Domain):
         super().from_dict()
         self.shard_id = self.attributes.get('shardId')
         self.game_mode = self.attributes.get('gameMode')
+
+
+class Weaponmasterysummary(Domain):
+
+    def from_dict(self):
+        super().from_dict()
+        self.platform = self.attributes.get('platform')
+        self.weapon_summaries = self.attributes.get('weaponSummaries')
+        self.latest_match_id = self.attributes.get('latestMatchId')
